% Nom du fichier : resolution.m
% 
% Appel de la fonction :
% [U,F]=conditions_limites(Tnn);
% 
% DESCRIPTION GENERALE
% - Fonction permettant de prendre en compte les conditions limites en
% force (F) et en dplacemnt (U).
% 
% DESCRITPION DES ENTREES DE LA FONCTION
% - Tnn : table de numrotation des noeuds, permet de reprer rapidement
% les noeuds sur les bords ou au centre.
%
% DESCRIPTION DES SORTIES DE LA FONCTION
% - U : dplacement impos. Vecteur de taille gale au nombre de ddl (2xle
% nbre d enoeuds dans notre cas). Si U(ii) = i, alors, le dplacement est
% inconnu (non impos)
% - F : force impose. Vecteur de taille gale au nombre de ddl (2xle
% nbre d enoeuds dans notre cas). Si F(ii) = i, alors, la force est
% inconnue, c'est  dire qu'il y a un dplacement impos. Si F(ii)=0, alors
% c'est un bord libre, ou c'est dans la structure o les dplacements sont
% recherchs.
%mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm


function [U,F]=conditions_limites(Tnn,l,h,ne)

%mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm
% Conditions limites :
% disp('        -> Mise en place des conditions limites');

% Efforts imposs sur des noeuds en particuliers (diples cellulaires) :
% f = 1; % Force unitaire de tension du diple en kN

% Initialisaton des vecteurs forces et dplacements :
% L'astuce est de dire que lorsque la composante est gale  i (nbre
% complexe), alors la composante de dplacement est inconnue.
nn(1)=size(Tnn,2);
nn(2)=size(Tnn,1);
ne = nn-1;
nnt = prod(nn);
%net=prod(ne);
Ux=i*ones(nnt,1);
Uy=i*ones(nnt,1);
Fx=i*ones(nnt,1);
Fy=i*ones(nnt,1);
U=i*ones(2*nnt,1);
F=i*ones(2*nnt,1);

% Dplacements imposs (conditions limites)
%% Bord de gauche
%Ux(Tnn(:,1))=0;
%Uy(Tnn(:,1))=0;
%% Point en bas  gauche:
Ux(Tnn(1,1))=0;
%% Bord en bas:
Uy(Tnn(1,:))=0;
%% Point en haut  gauche:
%Ux(Tnn(nn(1),1))=0;
%% Bord en haut:
Uy(Tnn(nn(1),:))=-0.1;
%% Bord  droite:
%Ux(Tnn(:,nn(2)))=0;
% Uy(Tnn(:,nn(2)))=0;

% %% Efforts imposs :
% pression=1;
% f = pression*l/ne(1); % Effort nodal
% %% Bord du haut:
% Fx(Tnn(nn(1),:))=0;
% Fy(Tnn(nn(1),:))=-f;
% Fy(Tnn(nn(1),1))=-f/2;
% Fy(Tnn(nn(1),end))=-f/2;

% Mise  zros des efforts si U impos
for ii=1:1:nnt
    if Ux(ii)==i && Fx(ii)==i
        Fx(ii)=0;
    end
    if Uy(ii)==i && Fy(ii)==i
        Fy(ii)=0;
    end
end

% Assemblage pour avoir U et F:
for ii=1:1:nnt
    U(2*ii-1)=Ux(ii);
    U(2*ii)=Uy(ii);
    F(2*ii-1)=Fx(ii);
    F(2*ii)=Fy(ii);
end
clear Ux Uy ii Fx Fy Liste_noeuds_pression_y
%mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm

end

